pub fn can_contain(tag: &str, child: &str) -> boolExpand description
&str wrapper over the canonical can_contain_sym; interns both names and
delegates. Kept for call sites that hold string names rather than SymStr.
pub fn can_contain(tag: &str, child: &str) -> bool&str wrapper over the canonical can_contain_sym; interns both names and
delegates. Kept for call sites that hold string names rather than SymStr.