decode_qname

Function decode_qname 

pub fn decode_qname(codetag: &str) -> Result<(Option<String>, String)>
Given a Qualified name, possibly prefixed with a namespace prefix, as defined by the code namespace mapping, return the NamespaceURI and localname.