can_contain_sym

Function can_contain_sym 

pub fn can_contain_sym(tag: SymStr, child: SymStr) -> bool
A check for allowed direct element containment, using ticket-based SymStr names.

TODO: This is a major code smell, experimental prototyping to see how to interoperate strings with the inerned arena. can_contain and can_contain_sym should be implemented once, and one should be an interning-only helper.