pub fn decode_qname_sym(sym: SymStr) -> Result<(Option<String>, String)>Expand description
TODO: We need a proper data model to deal with the Symbol - String distinction. For now let’s allocate strings and release the arena, but this is a CODE SMELL!